diff options
| author | Joanne Koong <joannelkoong@gmail.com> | 2026-09-16 11:44:24 -0700 |
|---|---|---|
| committer | Miklos Szeredi <mszeredi@redhat.com> | 2026-09-25 15:12:05 +0200 |
| commit | b46e0966741143366b5e9aafd3e85e297fd2f365 (patch) | |
| tree | 2174639acc47380473738765d6166420c6edbc36 /tools/lib/python | |
| parent | a68d10dd8f3d408df9b17bb7ad0054d1272b136c (diff) | |
| download | linux-next-b46e0966741143366b5e9aafd3e85e297fd2f365.tar.gz linux-next-b46e0966741143366b5e9aafd3e85e297fd2f365.zip | |
fuse: enable large folios
Enable large folios, capping the max order at the largest request fuse
can issue, so a folio always fits within a single request. The order
range minimum is 0, so under memory pressure the allocator falls back to
smaller folios.
Benchmarks (libfuse passthrough_hp, buffered fio, single job, 4 GiB
file, medians, NUMA-pinned, performance governor, strictlimiting on by
default):
tmpfs backing (page-cache bound):
workload bs large folios off on delta
seq read, cold, 128k 3110 MiB/s 4514 MiB/s +45%
seq read, cold, 1M 3079 MiB/s 5181 MiB/s +68%
seq read, warm, 128k 2438 MiB/s 4486 MiB/s +84%
seq read, warm, 1M 2403 MiB/s 5123 MiB/s +113%
writeback write, seq,128k 1211 MiB/s 1699 MiB/s +40%
writeback write, seq, 1M 1462 MiB/s 2208 MiB/s +51%
writeback write, rand,128k 1101 MiB/s 1757 MiB/s +60% +
writeback write, rand, 1M 1284 MiB/s 2228 MiB/s +74% +
xfs on NVMe backing (device bound for cold I/O):
workload bs large folios off on delta
seq read, cold, 128k 2030 MiB/s 2172 MiB/s +7% *
seq read, cold, 1M 1999 MiB/s 2181 MiB/s +9% *
seq read, warm, 128k 2451 MiB/s 4939 MiB/s +101%
seq read, warm, 1M 2340 MiB/s 5639 MiB/s +141%
writeback write, seq,128k 637 MiB/s 747 MiB/s +17% *
writeback write, seq, 1M 694 MiB/s 833 MiB/s +20% *
writeback write, rand,128k 1004 MiB/s 1648 MiB/s +64% +
writeback write, rand, 1M 1171 MiB/s 2055 MiB/s +75% +
(*) device-bandwidth bound. Not much throughput gain but system cpu
utilization was roughly halved
(+) random write was tested as an overwrite of a hot region (under
writeback, this is page-cache bound, so the gain comes from lower
per-folio cpu overhead rather than higher backing-device throughput)
Random reads (4k and 128k) and writethrough writes were neutral with
no regression (no read-modify-write or read-amplification penalty from
large folios)
More information about the benchmark setup and results are in
https://github.com/joannekoong/linux/commits/fuse_large_folios_benchmarks/
Reviewed-by: Horst Birthelmer <hbirthelmer@ddn.com>
Reviewed-by: Jingbo Xu <jefflexu@linux.alibaba.com>
Signed-off-by: Joanne Koong <joannelkoong@gmail.com>
Signed-off-by: Miklos Szeredi <mszeredi@redhat.com>
Diffstat (limited to 'tools/lib/python')
0 files changed, 0 insertions, 0 deletions
